@@ -20,9 +20,7 @@
 #include <QMutexLocker>
 #include <QRecursiveMutex>
 #include <QTimer>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
 #include <QRandomGenerator>
-#endif
 
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/icore.h>
@@ -295,8 +293,10 @@ public:
 using EnvironmentInformationListRepo
     = ItemRepository<EnvironmentInformationListItem, EnvironmentInformationListRequest>;
 
-template <>
-class ItemRepositoryFor<EnvironmentInformationListItem>
+struct EnvironmentInformationList {
+};
+template<>
+class ItemRepositoryFor<EnvironmentInformationList>
 {
     friend struct LockedItemRepository;
     static EnvironmentInformationListRepo& repo()
@@ -305,16 +305,15 @@ class ItemRepositoryFor<EnvironmentInformationListItem>
         static EnvironmentInformationListRepo repo(QStringLiteral("Environment Lists"), &mutex);
         return repo;
     }
-
-public:
-    static void init() { repo(); }
 };
 
 /// Maps top-context-indices to environment-information item.
 using EnvironmentInformationRepo = ItemRepository<EnvironmentInformationItem, EnvironmentInformationRequest>;
 
-template <>
-class ItemRepositoryFor<EnvironmentInformationItem>
+struct EnvironmentInformation {
+};
+template<>
+class ItemRepositoryFor<EnvironmentInformation>
 {
     friend struct LockedItemRepository;
     static EnvironmentInformationRepo& repo()
@@ -323,9 +322,6 @@ class ItemRepositoryFor<EnvironmentInformationItem>
         static EnvironmentInformationRepo repo(QStringLiteral("Environment Information"), &mutex);
         return repo;
     }
-
-public:
-    static void init() { repo(); }
 };
 
 class DUChainPrivate;
@@ -522,7 +518,7 @@ public:
     void addEnvironmentInformation(ParsingEnvironmentFilePointer info)
     {
         Q_ASSERT(!findInformation(info->indexedTopContext().index()));
-        Q_ASSERT(LockedItemRepository::read<EnvironmentInformationItem>([&](const EnvironmentInformationRepo& repo) {
+        Q_ASSERT(LockedItemRepository::read<EnvironmentInformation>([&](const EnvironmentInformationRepo& repo) {
             return repo.findIndex(info->indexedTopContext().index()) == 0;
         }));
 
@@ -550,7 +546,7 @@ public:
             removed2 = m_indexEnvironmentInformations.remove(infoIndex);
         }
 
-        LockedItemRepository::write<EnvironmentInformationListItem>(
+        LockedItemRepository::write<EnvironmentInformationList>(
             [infoIndex,
              request = EnvironmentInformationListRequest(info->url())](EnvironmentInformationListRepo& repo) mutable {
                 // Remove it from the environment information lists if it was there
@@ -568,7 +564,7 @@ public:
                 }
             });
 
-        LockedItemRepository::write<EnvironmentInformationItem>(
+        LockedItemRepository::write<EnvironmentInformation>(
             [infoIndex, removed, removed2](EnvironmentInformationRepo& repo) {
                 const uint index = repo.findIndex(infoIndex);
                 if (index) {
@@ -592,7 +588,7 @@ public:
             KDevVarLengthArray<uint> topContextIndices;
             // First store all the possible indices into the KDevVarLengthArray, so we can process them without holding
             // a mutex locked
-            LockedItemRepository::read<EnvironmentInformationListItem>(
+            LockedItemRepository::read<EnvironmentInformationList>(
                 [&topContextIndices,
                  request = EnvironmentInformationListRequest(url)](const EnvironmentInformationListRepo& repo) {
                     const EnvironmentInformationListItem* item = repo.findItem(request);
@@ -716,7 +712,7 @@ public:
             for (const ParsingEnvironmentFilePointer& file : qAsConst(check)) {
                 EnvironmentInformationRequest req(file.data());
 
-                LockedItemRepository::write<EnvironmentInformationItem>([&](EnvironmentInformationRepo& repo) {
+                LockedItemRepository::write<EnvironmentInformation>([&](EnvironmentInformationRepo& repo) {
                     uint index = repo.findIndex(req);
 
                     if (file->d_func()->isDynamic()) {
@@ -758,7 +754,7 @@ public:
             storeInformationList(url);
 
             //Access the data in the repository, so the bucket isn't unloaded
-            const auto foundItem = LockedItemRepository::read<EnvironmentInformationListItem>(
+            const auto foundItem = LockedItemRepository::read<EnvironmentInformationList>(
                 [request = EnvironmentInformationListRequest(url)](const EnvironmentInformationListRepo& repo) {
                     return static_cast<bool>(repo.findItem(request));
                 });
@@ -842,7 +838,6 @@ public:
         }
 
         QTime startTime = QTime::currentTime();
-        PersistentSymbolTable::self().clearCache();
 
         storeAllInformation(!retries, writeLock); //Puts environment-information into a repository
 
@@ -953,11 +948,7 @@ unloadContexts:
                  it != m_fileEnvironmentInformations.end();) {
                 ParsingEnvironmentFile* f = it->data();
                 Q_ASSERT(f->d_func()->classId);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 if (f->ref.loadRelaxed() == 1) {
-#else
-                if (f->ref.load() == 1) {
-#endif
                     Q_ASSERT(!f->d_func()->isDynamic()); //It cannot be dynamic, since we have stored before
                     //The ParsingEnvironmentFilePointer is only referenced once. This means that it does not belong to any
                     //loaded top-context, so just remove it to save some memory and processing time.
@@ -1044,7 +1035,7 @@ unloadContexts:
 
         // Step two: Check if it is on disk, and if is, load it
         //  TODO: this looks pretty dubious, shouldn't we keep the repo locked while operating on the item?
-        const auto item = LockedItemRepository::read<EnvironmentInformationItem>(
+        const auto item = LockedItemRepository::read<EnvironmentInformation>(
             [req = EnvironmentInformationRequest(topContextIndex)](const EnvironmentInformationRepo& repo) {
                 return repo.findItem(req);
             });
@@ -1094,8 +1085,9 @@ unloadContexts:
         qCDebug(LANGUAGE) << "cleaning top-contexts";
         CleanupListVisitor visitor;
         uint startPos = 0;
-        LockedItemRepository::write<EnvironmentInformationItem>(
-            [&visitor](EnvironmentInformationRepo& repo) { repo.visitAllItems(visitor); });
+        LockedItemRepository::write<EnvironmentInformation>([&visitor](EnvironmentInformationRepo& repo) {
+            repo.visitAllItems(visitor);
+        });
 
         int checkContextsCount = maxFinalCleanupCheckContexts;
         int percentageOfContexts = (visitor.checkContexts.size() * 100) / minimumFinalCleanupCheckContextsPercentage;
@@ -1103,12 +1095,8 @@ unloadContexts:
         if (checkContextsCount < percentageOfContexts)
             checkContextsCount = percentageOfContexts;
 
-        if (visitor.checkContexts.size() > ( int )checkContextsCount)
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+        if (visitor.checkContexts.size() > (int)checkContextsCount)
             startPos = QRandomGenerator::global()->bounded(visitor.checkContexts.size() - checkContextsCount);
-#else
-            startPos = qrand() % (visitor.checkContexts.size() - checkContextsCount);
-#endif
 
         int endPos = startPos + maxFinalCleanupCheckContexts;
         if (endPos > visitor.checkContexts.size())
@@ -1192,7 +1180,7 @@ private:
             }
         }
 
-        LockedItemRepository::write<EnvironmentInformationListItem>(
+        LockedItemRepository::write<EnvironmentInformationList>(
             [&, request = EnvironmentInformationListRequest(url)](EnvironmentInformationListRepo& repo) mutable {
                 const uint index = repo.findIndex(request);
 
@@ -1291,10 +1279,9 @@ void DUChain::initialize()
     // being 0 and hence crashes at some point later when accessing the contents via
     // read. See https://bugs.kde.org/show_bug.cgi?id=250779
     RecursiveImportRepository::repository();
-    RecursiveImportCacheRepository::repository();
 
-    ItemRepositoryFor<EnvironmentInformationListItem>::init();
-    ItemRepositoryFor<EnvironmentInformationItem>::init();
+    LockedItemRepository::initialize<EnvironmentInformationList>();
+    LockedItemRepository::initialize<EnvironmentInformation>();
 
     // similar to above, see https://bugs.kde.org/show_bug.cgi?id=255323
     initDeclarationRepositories();
