@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright 2010 Andreas Pakulat <apaku@gmx.de>                         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Andreas Pakulat <apaku@gmx.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "test_projectmodel.h"
 
@@ -25,15 +12,10 @@
 #include <QMimeType>
 #include <QMimeDatabase>
 #include <QSignalSpy>
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
 #include <QAbstractItemModelTester>
-#endif
 
 #include <projectmodel.h>
 #include <projectproxymodel.h>
-#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
-#include <tests/modeltest.h>
-#endif
 #include <tests/testproject.h>
 #include <tests/kdevsignalspy.h>
 #include <tests/autotestshell.h>
@@ -58,17 +40,9 @@ void TestProjectModel::initTestCase()
 
     qRegisterMetaType<QModelIndex>("QModelIndex");
     model = ICore::self()->projectController()->projectModel();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
     new QAbstractItemModelTester( model, this );
-#else
-    new ModelTest( model, this );
-#endif
     proxy = new ProjectProxyModel( model );
-#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
     new QAbstractItemModelTester(proxy, proxy);
-#else
-    new ModelTest(proxy, proxy);
-#endif
     proxy->setSourceModel(model);
 }
 
