@@ -1,24 +1,12 @@
-/* This file is part of the KDevelop project
-Copyright 2002 Falk Brettschneider <falkbr@kdevelop.org>
-Copyright 2003 John Firebaugh <jfirebaugh@kde.org>
-Copyright 2006 Adam Treat <treat@kde.org>
-Copyright 2006, 2007 Alexander Dymo <adymo@kdevelop.org>
+/*
+    SPDX-FileCopyrightText: 2002 Falk Brettschneider <falkbr@kdevelop.org>
+    SPDX-FileCopyrightText: 2003 John Firebaugh <jfirebaugh@kde.org>
+    SPDX-FileCopyrightText: 2006 Adam Treat <treat@kde.org>
+    SPDX-FileCopyrightText: 2006, 2007 Alexander Dymo <adymo@kdevelop.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
-
-You should have received a copy of the GNU Library General Public License
-along with this library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 #include "mainwindow.h"
 #include "mainwindow_p.h"
 
