@@ -11,20 +11,13 @@
 
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KMessageBox_KDevCompat>
 
 #include <QDBusConnectionInterface>
 #include <QFile>
 #include <QDir>
 
 namespace KDevelop {
-
-using TextStreamFunction = QTextStream& (*)(QTextStream&);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-constexpr TextStreamFunction endl = Qt::endl;
-#else
-constexpr TextStreamFunction endl = ::endl;
-#endif
-
 QString lockFileForSession( const QString& id )
 {
     return SessionController::sessionDirectory( id ) + QLatin1String("/lock");
@@ -156,7 +149,11 @@ QString SessionLock::handleLockedSession(const QString& sessionName, const QStri
                                                                     timeout_ms );
         if( reply.type() == QDBusMessage::ReplyMessage ) {
             QTextStream out(stdout);
-            out << i18nc( "@info:shell", "Running %1 instance (PID: %2) detected, making this one visible instead of starting a new one", runInfo.holderApp, runInfo.holderPid ) << endl;
+            out << i18nc(
+                "@info:shell",
+                "Running %1 instance (PID: %2) detected, making this one visible instead of starting a new one",
+                runInfo.holderApp, runInfo.holderPid)
+                << Qt::endl;
             return QString();
         } else {
             qCWarning(SHELL) << i18nc("@info:shell", "Running %1 instance (PID: %2) is apparently hung", runInfo.holderApp, runInfo.holderPid);
@@ -190,13 +187,13 @@ QString SessionLock::handleLockedSession(const QString& sessionName, const QStri
     choose.setText(i18nc("@action:button", "Choose Another Session"));
 
     KGuiItem cancel = KStandardGuiItem::quit();
-    int ret = KMessageBox::warningYesNoCancel(nullptr, errmsg, i18nc("@title:window", "Failed to Lock Session %1", sessionName),
-                                              retry, choose, cancel);
+    int ret = KMessageBox::warningTwoActionsCancel(
+        nullptr, errmsg, i18nc("@title:window", "Failed to Lock Session %1", sessionName), retry, choose, cancel);
     switch( ret ) {
-    case KMessageBox::Yes:
+    case KMessageBox::PrimaryAction:
         return sessionId;
 
-    case KMessageBox::No: {
+    case KMessageBox::SecondaryAction: {
         QString errmsg = i18nc("@info", "The session %1 is already active in another running instance.",
                                sessionName);
         return SessionController::showSessionChooserDialog(errmsg);
