@@ -1,23 +1,11 @@
-/***************************************************************************
- *   Copyright 2006-2007 Alexander Dymo <adymo@kdevelop.org>               *
- *   Copyright 2006 Andreas Pakulat <apaku@gmx.de>                         *
- *   Copyright 2016 Imran Tatriev <itatriev@gmail.com>                     *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2007 Alexander Dymo <adymo@kdevelop.org>
+    SPDX-FileCopyrightText: 2006 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2016 Imran Tatriev <itatriev@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
+
 #include "filemanager.h"
 
 #include <QDir>
@@ -136,7 +124,7 @@ void FileManager::updateNav( const QUrl& url )
 void FileManager::setupActions()
 {
     auto* acmBookmarks = new KActionMenu(QIcon::fromTheme(QStringLiteral("bookmarks")), i18nc("@title:menu", "Bookmarks"), this);
-    acmBookmarks->setDelayed(false);
+    acmBookmarks->setPopupMode(QToolButton::InstantPopup);
     m_bookmarkHandler = new BookmarkHandler(this, acmBookmarks->menu());
     acmBookmarks->setShortcutContext(Qt::WidgetWithChildrenShortcut);
 
