@@ -1,23 +1,8 @@
 /*
- * This file is part of KDevelop
- *
- * Copyright 2007 David Nolden <david.nolden.kdevelop@art-master.de>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007 David Nolden <david.nolden.kdevelop@art-master.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "quickopenplugin.h"
 
@@ -339,7 +324,6 @@ void QuickOpenPlugin::createActionsForMainWindow(Sublime::MainWindow* /*window*/
     m_quickOpenDefinition = actions.addAction(QStringLiteral("quick_open_jump_definition"));
     m_quickOpenDefinition->setText(i18nc("@action", "Jump to Definition"));
     m_quickOpenDefinition->setIcon(QIcon::fromTheme(QStringLiteral("go-jump-definition")));
-    actions.setDefaultShortcut(m_quickOpenDefinition, Qt::CTRL | Qt::Key_Comma);
     connect(m_quickOpenDefinition, &QAction::triggered, this, &QuickOpenPlugin::quickOpenDefinition, Qt::QueuedConnection);
 
     auto* quickOpenLine = new QWidgetAction(this);
@@ -704,7 +688,7 @@ void QuickOpenPlugin::quickOpenDefinition()
 
     IndexedString u = decl->url();
     KTextEditor::Cursor c = decl->rangeInCurrentRevision().start();
-    if (FunctionDefinition* def = FunctionDefinition::definition(decl)) {
+    if (auto* def = FunctionDefinition::definition(decl)) {
         def->activateSpecialization();
         u = def->url();
         c = def->rangeInCurrentRevision().start();
@@ -808,12 +792,6 @@ void QuickOpenPlugin::jumpToNearestFunction(QuickOpenPlugin::FunctionJumpDirecti
 
 struct CreateOutlineDialog
 {
-    CreateOutlineDialog() : dialog(nullptr)
-        , cursorDecl(nullptr)
-        , model(nullptr)
-    {
-    }
-
     void start()
     {
         if (!QuickOpenPlugin::self()->freeModel()) {
@@ -826,7 +804,7 @@ struct CreateOutlineDialog
             return;
         }
 
-        KDevelop::DUChainReadLocker lock(DUChain::lock());
+        DUChainReadLocker lock;
 
         TopDUContext* context = DUChainUtils::standardContextForUrl(doc->url());
 
@@ -859,26 +837,27 @@ struct CreateOutlineDialog
     void finish()
     {
         //Select the declaration that contains the cursor
-        if (cursorDecl && dialog) {
-            int num = 0;
-            for (const DUChainItem& item : qAsConst(items)) {
-                if (item.m_item.data() == cursorDecl) {
-                    QModelIndex index(model->index(num, 0, QModelIndex()));
-                    // Need to invoke the scrolling later. If we did it now, then it wouldn't have any effect,
-                    // apparently because the widget internals aren't initialized yet properly (although we've
-                    // already called 'widget->show()'.
-                    auto list = dialog->widget()->ui.list;
-                    QMetaObject::invokeMethod(list, "setCurrentIndex", Qt::QueuedConnection, Q_ARG(QModelIndex, index));
-                    QMetaObject::invokeMethod(list, "scrollTo", Qt::QueuedConnection, Q_ARG(QModelIndex, index), Q_ARG(QAbstractItemView::ScrollHint, QAbstractItemView::PositionAtCenter));
-                }
-                ++num;
+        if (cursorDecl.isValid() && dialog) {
+            auto it = std::find_if(items.constBegin(), items.constEnd(),
+                                   [this](const DUChainItem& item) { return item.m_item == cursorDecl; });
+            if (it != items.constEnd()) {
+                // Need to invoke the scrolling later. If we did it now, then it wouldn't have any effect,
+                // apparently because the widget internals aren't initialized yet properly (although we've
+                // already called 'widget->show()'.
+                auto list = dialog->widget()->ui.list;
+                const auto num = std::distance(items.constBegin(), it);
+                QTimer::singleShot(0, list, [list, num]() {
+                    const auto index = list->model()->index(num, 0, {});
+                    list->setCurrentIndex(index);
+                    list->scrollTo(index, QAbstractItemView::PositionAtCenter);
+                });
             }
         }
     }
     QPointer<QuickOpenWidgetDialog> dialog;
-    Declaration* cursorDecl;
+    IndexedDeclaration cursorDecl;
     QVector<DUChainItem> items;
-    QuickOpenModel* model;
+    QuickOpenModel* model = nullptr;
 };
 
 class OutlineQuickopenWidgetCreator
