@@ -1,19 +1,7 @@
-/* This file is part of KDevelop
-    Copyright 2011 Aleix Pol Gonzalez <aleixpol@kde.org>
+/*
+    SPDX-FileCopyrightText: 2011 Aleix Pol Gonzalez <aleixpol@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "welcomepageview.h"
@@ -22,6 +10,7 @@
 #include "sessionsmodel.h"
 
 #include <KDeclarative/KDeclarative>
+#include <KLocalizedContext>
 
 #include <QQmlContext>
 #include <QQmlComponent>
@@ -47,11 +36,10 @@ WelcomePageWidget::WelcomePageWidget(const QList<IProject*> & /*projects*/, QWid
     qmlRegisterType<SessionsModel>("org.kdevelop.welcomepage", 4, 3, "SessionsModel");
 
     //setup kdeclarative library
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(engine());
-    kdeclarative.setTranslationDomain(QStringLiteral("kdevwelcomepage"));
-    kdeclarative.setupEngine(engine());
-    kdeclarative.setupContext();
+    KDeclarative::KDeclarative::setupEngine(engine());
+    KLocalizedContext *localizedContextObject = new KLocalizedContext(engine());
+    localizedContextObject->setTranslationDomain(QStringLiteral("kdevwelcomepage"));
+    engine()->rootContext()->setContextObject(localizedContextObject);
 
     setResizeMode(QQuickWidget::SizeRootObjectToView);
 
